import { MouseEvent } from 'react'

export function removeFromObjRecursive(nodeName: string, nextJsDataObject: any) {
    return JSON.parse(
        JSON.stringify(nextJsDataObject, function (key, value) {
            if (key !== nodeName) return value
        })
    )
}

export function replaceEmailsRecursive(name: string, nextJsDataObject: any) {
    return JSON.parse(
        JSON.stringify(nextJsDataObject, function (key, value) {
            if (key === name) return encodeEmail(value)
            return value
        })
    )
}

export function encodeEmail(emailAddress: string) {
    return btoa(emailAddress)
}

export function decodeEmail(encodedEmailAddress: string) {
    return atob(encodedEmailAddress)
}

export function handleMailtoEvent(mouseEvent: MouseEvent<HTMLAnchorElement>) {
    const targetElement = mouseEvent.currentTarget
    const base = targetElement.dataset.base
    const mail = decodeEmail(base)
    targetElement.href = 'mailto:' + mail
    return true
}

//  Converts an ISO date into long German date format
export function convertIsoDateToLongDate(theDate: string) {
    const monthNames = ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']

    // Check format
    const regexp = /\d{4}-[01]\d-[0-3]\d/
    if (!regexp.test(theDate)) {
        return '#INVALID'
    }

    // Evaluate string content, e.-g. 2023-09-15
    const year = theDate.substring(0, 4)
    const month = parseInt(theDate.substring(5, 7))
    const dayInMonth = parseInt(theDate.substring(8))

    return dayInMonth + '. ' + monthNames[month - 1] + ' ' + year
}

export default {
    removeFromObjRecursive,
    replaceEmailsRecursive,
    encodeEmail,
    decodeEmail,
    convertIsoDateToLongDate,
    handleMailtoEvent,
}
